@@ -1,6 +1,6 @@
 from beta9 import Bot, BotContext, BotEventType, BotLocation, env
 from beta9.abstractions import experimental
-from beta9.abstractions.container import Container
+from beta9.abstractions.base.container import Container
 from beta9.abstractions.endpoint import ASGI as asgi
 from beta9.abstractions.endpoint import Endpoint as endpoint
 from beta9.abstractions.endpoint import RealtimeASGI as realtime
@@ -9,7 +9,7 @@ from beta9.abstractions.function import Schedule as schedule
 from beta9.abstractions.image import Image
 from beta9.abstractions.map import Map
 from beta9.abstractions.output import Output
-from beta9.abstractions.pod import CreatePodResult, Pod
+from beta9.abstractions.pod import Pod, PodInstance
 from beta9.abstractions.queue import SimpleQueue as Queue
 from beta9.abstractions.taskqueue import TaskQueue as task_queue
 from beta9.abstractions.volume import CloudBucket, CloudBucketConfig, Volume
@@ -41,5 +41,5 @@ __all__ = [
     "BotEventType",
     "BotLocation",
     "Pod",
-    "CreatePodResult",
+    "PodInstance",
 ]
